summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/main/java/org/bukkit/entity/LivingEntity.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/main/java/org/bukkit/entity/LivingEntity.java b/src/main/java/org/bukkit/entity/LivingEntity.java
index 5a30fa93..8b2fb74c 100644
--- a/src/main/java/org/bukkit/entity/LivingEntity.java
+++ b/src/main/java/org/bukkit/entity/LivingEntity.java
@@ -29,11 +29,11 @@ public interface LivingEntity extends Attributable, Entity, Damageable, Projecti
/**
* Gets the height of the living entity's eyes above its Location.
*
* @param ignoreSneaking if set to true, the effects of sneaking will be
* ignored
* @return height of the living entity's eyes above its location
*/
- public double getEyeHeight(boolean ignoreSneaking);
+ public double getEyeHeight(boolean ignorePose);
/**
* Get a Location detailing the current eye position of the living entity.
@@ -29,11 +29,11 @@ public interface LivingEntity extends Attributable, Entity, Damageable, Projecti
* Gets the height of the living entity's eyes above its Location.
*
- * @param ignoreSneaking if set to true, the effects of sneaking will be
- * ignored
+ * @param ignorePose if set to true, the effects of pose changes, eg
+ * sneaking and gliding will be ignored
* @return height of the living entity's eyes above its location
*/